@@ -566,13 +566,17 @@ class CreateOrderDetailModel(CreatedDeliveryOrderModel):
     waiter: Optional[OrderDetailWaiterModel]
     tab_name: Optional[str] = Field(alias="tabName")
 
+class COICreationStatusModel(str, Enum):
+    success = "Success"
+    in_progress = "InProgress"
+    error = "Error"
 
 class CreatedOrderInfoModel(BaseModel):
     id: str
     external_number: Optional[str] = Field(alias='externalNumber')
     organization_id: str = Field(alias='organizationId')
     timestamp: int
-    creation_status: Optional[str] = Field(alias='creationStatus')
+    creation_status: Optional[COICreationStatusModel] = Field(alias='creationStatus')
     error_info: Optional[ErrorInfoModel] = Field(alias="errorInfo")
     order: CreateOrderDetailModel
 
@@ -945,7 +949,8 @@ class BaseTipsTypesModel(BaseResponseModel):
 
 
 class BaseStatusModel(BaseModel):
-    state: str
+    exception: Optional[Any]
+    state: COICreationStatusModel
 
 
 class CSGProductModel(BaseModel):
